==> qt-creator-opensource-src-4.0.2.zip: qt-creator-opensource-src-4.0.2/src/plugins/todo/cpptodoitemsscanner.h <==
/****************************************************************************
**
** Copyright (C) 2016 Dmitry Savchenko
** Copyright (C) 2016 Vasiliy Sorokin
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#ifndef CPPTODOITEMSSCANNER_H
#define CPPTODOITEMSSCANNER_H

#include "todoitemsscanner.h"

#include <cpptools/cppmodelmanager.h>

namespace Todo {
namespace Internal {

class CppTodoItemsScanner : public TodoItemsScanner
{
    Q_OBJECT

public:
    explicit CppTodoItemsScanner(const KeywordList &keywordList, QObject *parent = 0);

protected:
    void scannerParamsChanged();

private slots:
    void documentUpdated(CPlusPlus::Document::Ptr doc);

private:
    void processDocument(CPlusPlus::Document::Ptr doc);
};

}
}

#endif // CPPTODOITEMSSCANNER_H

==> qt-creator-opensource-src-4.10.2.zip: qt-creator-opensource-src-4.10.2/src/plugins/todo/cpptodoitemsscanner.h <==
/****************************************************************************
**
** Copyright (C) 2016 Dmitry Savchenko
** Copyright (C) 2016 Vasiliy Sorokin
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "todoitemsscanner.h"

#include <cpptools/cppmodelmanager.h>

namespace Todo {
namespace Internal {

class CppTodoItemsScanner : public TodoItemsScanner
{
public:
    explicit CppTodoItemsScanner(const KeywordList &keywordList, QObject *parent = nullptr);

protected:
    void scannerParamsChanged() override;

private:
    void documentUpdated(CPlusPlus::Document::Ptr doc);
    void processDocument(CPlusPlus::Document::Ptr doc);
};

}
}
